@@ -2,7 +2,8 @@ import multiprocessing
 import threading
 import argparse
 from FreeTAKServer.controllers.CreateStartupFilesController import CreateStartupFilesController
-from FreeTAKServer.controllers.services.DataPackageServer import FlaskFunctions
+from FreeTAKServer.controllers.services.TCPDataPackageService import TCPDataPackageService as TCPFlaskFunctions
+from FreeTAKServer.controllers.services.SSLDataPackageService import SSLDataPackageService as SSLFlaskFunctions
 from FreeTAKServer.controllers.configuration.OrchestratorConstants import OrchestratorConstants
 from FreeTAKServer.controllers.configuration.LoggingConstants import LoggingConstants
 from FreeTAKServer.controllers.CreateLoggerController import CreateLoggerController
@@ -12,7 +13,10 @@ from FreeTAKServer.model.SimpleClient import SimpleClient
 import time
 from FreeTAKServer.controllers.AddDataToCoTList import AddDataToCoTList
 from FreeTAKServer.model.FilterGroup import FilterGroup
+from FreeTAKServer.controllers.services.SSLCoTServiceController import SSLCoTServiceController
 from FreeTAKServer.controllers.services.TCPCoTServiceController import TCPCoTServiceController
+from FreeTAKServer.controllers.services.FederationClientServiceController import FederationClientServiceController
+from FreeTAKServer.controllers.services.FederationServerServiceController import FederationServerServiceController
 from FreeTAKServer.controllers.DatabaseControllers.DatabaseController import DatabaseController
 
 loggingConstants = LoggingConstants()
@@ -23,12 +27,13 @@ class FTS:
 
     def __init__(self):
         self.CoTService = None
-        self.DataPackageService = None
+        self.TCPDataPackageService = None
         self.UserCommand = None
         self.killSwitch = False
         self.ReceiveConnectionsReset = None
         self.CoTPoisonPill = None
         self.ClientDataPipe = None
+        self.SSLClientDataPipe = None
         self.clientArray = []
         self.socketCount = 0
         self.pipeList = {}
@@ -102,41 +107,177 @@ class FTS:
             return -1
         return 1
 
-    def start_data_package_service(self, FTSServiceStartupConfigObject):
+    def start_tcp_data_package_service(self, FTSServiceStartupConfigObject):
         try:
+            tcp_data_package_service_pipe, self.tcp_data_package_service_pipe = multiprocessing.Pipe(duplex=True)
             print('start 213')
-            self.DataPackageService = multiprocessing.Process(target=FlaskFunctions().startup,
-                                                              args=(FTSServiceStartupConfigObject.DataPackageService.DataPackageServiceIP, FTSServiceStartupConfigObject.DataPackageService.DataPackageServicePort))
+            self.TCPDataPackageService = multiprocessing.Process(target=TCPFlaskFunctions().startup,
+                                                                 args=(FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServiceIP, FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServicePort, tcp_data_package_service_pipe))
             print('starting now')
-            self.DataPackageService.start()
+            self.TCPDataPackageService.start()
+            self.pipeList['tcp_data_package_service_pipe'] = self.tcp_data_package_service_pipe
+            self.FilterGroup.sources.append(self.tcp_data_package_service_pipe)
             time.sleep(2)
             return 1
         except Exception as e:
             logger.error('there has been an exception in the individual starting of the Data Packages Service ' + str(e))
             return -1
 
-    def stop_data_package_service(self):
+    def stop_tcp_data_package_service(self):
         try:
-            self.DataPackageService.terminate()
+            self.TCPDataPackageService.terminate()
         except Exception as e:
             logger.error("there's been an exception in the termination of DataPackage Service " + str(e))
             return -1
         try:
-            self.DataPackageService.join()
+            self.TCPDataPackageService.join()
         except Exception as e:
             logger.error("there's been an exception in the joining of DataPackage Service " + str(e))
             return -1
         return 1
 
+    def start_ssl_data_package_service(self, FTSServiceStartupConfigObject):
+        try:
+            print('start 213')
+            ssl_data_package_service, self.ssl_data_package_service = multiprocessing.Pipe(duplex=True)
+            self.SSLDataPackageService = multiprocessing.Process(target=SSLFlaskFunctions().startup,
+                                                              args=(FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceIP, FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServicePort, ssl_data_package_service))
+            print('starting SSL now')
+            self.SSLDataPackageService.start()
+            self.pipeList['ssl_data_package_service'] = self.ssl_data_package_service
+            self.FilterGroup.sources.append(self.ssl_data_package_service)
+            time.sleep(2)
+            return 1
+        except Exception as e:
+            logger.error('there has been an exception in the individual starting of the Data Packages Service ' + str(e))
+            return -1
+
+    def stop_ssl_data_package_service(self):
+        try:
+            self.SSLDataPackageService.terminate()
+        except Exception as e:
+            logger.error("there's been an exception in the termination of DataPackage Service " + str(e))
+            return -1
+        try:
+            self.SSLDataPackageService.join()
+        except Exception as e:
+            logger.error("there's been an exception in the joining of DataPackage Service " + str(e))
+            return -1
+        return 1
+
+    def start_SSL_CoT_service(self, FTSServiceStartupConfigObject):
+        try:
+            self.SSLClientDataPipe, SSLClientDataPipeParentChild = multiprocessing.Pipe()
+            self.SSLCoTServicePipe, self.SSLCoTServiceFTSPipe = multiprocessing.Pipe()
+            self.SSLCoTPoisonPill = multiprocessing.Event()
+            self.SSLCoTPoisonPill.set()
+            self.ReceiveConnectionsReset = multiprocessing.Event()
+            self.SSLCoTService = multiprocessing.Process(target=SSLCoTServiceController().start, args=(FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceIP, FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServicePort, self.SSLCoTPoisonPill, SSLClientDataPipeParentChild, self.ReceiveConnectionsReset, self.SSLCoTServicePipe))
+            self.SSLCoTService.start()
+            self.pipeList['SSLCoTServiceFTSPipe'] = self.SSLCoTServiceFTSPipe
+            self.FilterGroup.sources.append(self.SSLCoTServiceFTSPipe)
+            self.FilterGroup.receivers.append(self.SSLCoTServiceFTSPipe)
+            print('SSL CoTService started')
+            return 1
+        except Exception as e:
+            logger.error('an exception has been thrown in SSL CoT service startup ' + str(e))
+            return -1
+
+    def stop_SSL_CoT_service(self):
+        try:
+            self.SSLClientDataPipe.close()
+            self.SSLCoTPoisonPill.clear()
+
+            time.sleep(0.1)
+            if self.CoTService.is_alive():
+                self.CoTService.terminate()
+                self.CoTService.join()
+            else:
+                self.CoTService.join()
+
+            self.FilterGroup.sources.remove(self.TCPCoTServiceFTSPipe)
+            self.FilterGroup.receivers.remove(self.TCPCoTServiceFTSPipe)
+
+        except Exception as e:
+            logger.error("there's been an exception in the stopping of CoT Service " + str(e))
+            return -1
+        return 1
+
+    def start_federation_client_service(self, FTSServiceStartupConfigObject):
+        try:
+            ip = FTSServiceStartupConfigObject.FederationClientService.FederationClientServiceIP
+            port = FTSServiceStartupConfigObject.FederationClientService.FederationClientServicePort
+            FederationClientServicePipe, self.FederationClientServicePipeFTS = multiprocessing.Pipe()
+            self.FederationClientService = multiprocessing.Process(
+                target=FederationClientServiceController(FederationClientServicePipe, ip, port).start, args=())
+            self.FederationClientService.start()
+            self.pipeList['FederationClientServiceFTSPipe'] = self.FederationClientServicePipeFTS
+            self.FilterGroup.sources.append(self.FederationClientServicePipeFTS)
+            self.FilterGroup.receivers.append(self.FederationClientServicePipeFTS)
+            return 1
+        except:
+            return -1
+
+    def stop_federation_client_service(self):
+        try:
+            if self.FederationClientService.is_alive():
+                self.FederationClientService.terminate()
+                self.FederationClientService.join()
+            else:
+                self.FederationClientService.join()
+
+            self.FilterGroup.sources.remove(self.FederationClientServicePipeFTS)
+            self.FilterGroup.receivers.remove(self.FederationClientServicePipeFTS)
+            return 1
+        except:
+            return -1
+        
+    def start_federation_server_service(self, FTSServiceStartupConfigObject):
+            try:
+                ip = FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceIP
+                port = FTSServiceStartupConfigObject.FederationServerService.FederationServerServicePort
+                FederationServerServicePipe, self.FederationServerServicePipeFTS = multiprocessing.Pipe()
+                self.FederationServerService = multiprocessing.Process(
+                    target=FederationServerServiceController(FederationServerServicePipe, ip, port).start, args=())
+                self.FederationServerService.start()
+                self.pipeList['FederationServerServiceFTSPipe'] = self.FederationServerServicePipeFTS
+                self.FilterGroup.sources.append(self.FederationServerServicePipeFTS)
+                self.FilterGroup.receivers.append(self.FederationServerServicePipeFTS)
+                return 1
+            except:
+                return -1
+
+    def stop_federation_server_service(self):
+        try:
+            if self.FederationServerService.is_alive():
+                self.FederationServerService.terminate()
+                self.FederationServerService.join()
+            else:
+                self.FederationServerService.join()
+
+            self.FilterGroup.sources.remove(self.FederationServerServicePipeFTS)
+            self.FilterGroup.receivers.remove(self.FederationServerServicePipeFTS)
+            return 1
+        except:
+            return -1
+
     #change object name to FTSServiceStartupConfigObject
     def start_all(self, FTSServiceStartupConfigObject):
         try:
             self.FTSServiceStartupConfigObject = FTSServiceStartupConfigObject
-            if FTSServiceStartupConfigObject.DataPackageService.DataPackageServiceStatus == 'start':
-                self.start_data_package_service(FTSServiceStartupConfigObject)
+            if FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServiceStatus == 'start':
+                self.start_tcp_data_package_service(FTSServiceStartupConfigObject)
 
-            elif FTSServiceStartupConfigObject.DataPackageService.DataPackageServiceStatus == 'stop':
-                self.stop_data_package_service()
+            elif FTSServiceStartupConfigObject.TCPDataPackageService.TCPDataPackageServiceStatus == 'stop':
+                self.stop_tcp_data_package_service()
+            else:
+                pass
+
+            if FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceStatus == 'start':
+                self.start_ssl_data_package_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.SSLDataPackageService.SSLDataPackageServiceStatus == 'stop':
+                self.stop_ssl_data_package_service()
             else:
                 pass
 
@@ -148,6 +289,33 @@ class FTS:
             else:
                 pass
 
+            if FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceStatus == 'start':
+                self.start_SSL_CoT_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.SSLCoTService.SSLCoTServiceStatus == 'stop':
+                self.stop_SSL_CoT_service()
+
+            else:
+                pass
+
+            if FTSServiceStartupConfigObject.FederationClientService.FederationClientServiceStatus == 'start':
+                self.start_federation_client_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.FederationClientService.FederationClientServiceStatus == 'stop':
+                self.stop_federation_client_service()
+
+            else:
+                pass
+
+            if FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus == 'start':
+                self.start_federation_server_service(FTSServiceStartupConfigObject)
+
+            elif FTSServiceStartupConfigObject.FederationServerService.FederationServerServiceStatus == 'stop':
+                self.stop_federation_server_service()
+
+            else:
+                pass
+
             return 1
         except Exception as e:
             logger.error('there has been an exception in FTS start_all ' + str(e))
@@ -211,6 +379,18 @@ class FTS:
     def check_server_status(self):
         return self.FTSServiceStartupConfigObject
 
+    def help(self):
+        print('start_all: to begin all services type')
+        print('start_CoT_service: to begin CoT service type')
+        print('start_data_package_service: to begin data package service  type')
+        print('stop_all: to terminate all services type')
+        print('stop_CoT_service: to terminate CoT service type')
+        print('stop_data_package_service: to begin data package service type')
+        print('check_service_status: to check the status of the services type')
+        print('show_users: to show connected user information type')
+        print('start_federation_client_service: to begin federation with another server')
+        print('kill: to kill the full server type')
+
     def show_users(self):
         '''
         this method is used only by commands submitted over the rest interface
@@ -294,8 +474,8 @@ class FTS:
                     pass
         except Exception as e:
             pass
-    
-    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, RestAPIPort, RestAPIIP, AutoStart):
+
+    def startup(self, CoTPort, CoTIP, DataPackagePort, DataPackageIP, RestAPIPort, RestAPIIP, SSLCoTPort, SSLCoTIP, AutoStart):
         try:
             if AutoStart == 'False':
                 StartupObject = FTSObj()
@@ -309,14 +489,17 @@ class FTS:
                 StartupObject.CoTService.CoTServicePort = CoTPort
                 StartupObject.CoTService.CoTServiceStatus = 'start'
 
-                StartupObject.DataPackageService.DataPackageServiceIP = DataPackageIP
-                StartupObject.DataPackageService.DataPackageServicePort = DataPackagePort
-                StartupObject.DataPackageService.DataPackageServiceStatus = 'start'
+                StartupObject.TCPDataPackageService.TCPDataPackageServiceIP = DataPackageIP
+                StartupObject.TCPDataPackageService.TCPDataPackageServicePort = DataPackagePort
+                StartupObject.TCPDataPackageService.TCPDataPackageServiceStatus = 'start'
 
                 StartupObject.RestAPIService.RestAPIServicePort = RestAPIPort
                 StartupObject.RestAPIService.RestAPIServiceIP = RestAPIIP
                 StartupObject.RestAPIService.RestAPIServiceStatus = 'start'
 
+                StartupObject.SSLCoTService.SSLCoTServiceStatus = 'start'
+                StartupObject.SSLCoTService.SSLCoTServiceIP = SSLCoTIP
+                StartupObject.SSLCoTService.SSLCoTServicePort = SSLCoTPort
                 self.start_restAPI_service(StartupObject)
 
                 self.start_all(StartupObject)
@@ -325,6 +508,7 @@ class FTS:
             while True:
                 self.checkPipes()
                 self.clientArray = self.receive_data_froCoT_service_thread(self.ClientDataPipe, self.clientArray)
+                self.clientArray = self.receive_data_froCoT_service_thread(self.SSLClientDataPipe, self.clientArray)
 
         except Exception as e:
             logger.error('exception in the startup of FTS ' + str(e))
@@ -336,10 +520,14 @@ if __name__ == "__main__":
                             default=FTSObj().CoTService.CoTServicePort)
         parser.add_argument('-CoTIP', type=str, help=OrchestratorConstants().COTIPDESC,
                             default=FTSObj().CoTService.CoTServiceIP)
+        parser.add_argument('-SSLCoTPort', type=int, help=OrchestratorConstants().SSLCOTPORTDESC,
+                            default=FTSObj().SSLCoTService.SSLCoTServicePort)
+        parser.add_argument('-SSLCoTIP', type=str, help=OrchestratorConstants().SSLCOTIPDESC,
+                            default=FTSObj().SSLCoTService.SSLCoTServiceIP)
         parser.add_argument('-DataPackagePort', type=int, help=OrchestratorConstants().APIPORTDESC,
-                            default=FTSObj().DataPackageService.DataPackageServicePort)
+                            default=FTSObj().TCPDataPackageService.TCPDataPackageServicePort)
         parser.add_argument('-DataPackageIP', type=str, help=OrchestratorConstants().APIPORTDESC,
-                            default=FTSObj().DataPackageService.DataPackageServiceIP)
+                            default=FTSObj().TCPDataPackageService.TCPDataPackageServiceIP)
         parser.add_argument('-RestAPIPort', type=int, help=OrchestratorConstants().APIPORTDESC,
                             default=FTSObj().RestAPIService.RestAPIServicePort)
         parser.add_argument('-RestAPIIP', type=str, help=OrchestratorConstants().APIPORTDESC,
@@ -347,6 +535,6 @@ if __name__ == "__main__":
         parser.add_argument('-AutoStart', type=str, help='wether or not you want all services to start or only the root service and the RestAPI service', default='True')
         args = parser.parse_args()
         CreateStartupFilesController()
-        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.RestAPIPort, args.RestAPIIP, args.AutoStart)
+        FTS().startup(args.CoTPort, args.CoTIP, args.DataPackagePort, args.DataPackageIP, args.RestAPIPort, args.RestAPIIP, args.SSLCoTPort, args.SSLCoTIP, args.AutoStart)
     except Exception as e:
         print(e)
\ No newline at end of file
